pub fn install_session(
session: Option<Rc<dyn ActiveSession>>,
) -> Option<Rc<dyn ActiveSession>>Expand description
Install session as the active keyed session on this thread, returning the prior one. The live
seal_active_checked / open_active path then routes through it until it is replaced/cleared.