pub fn with_session<T>(
session: Option<Rc<dyn ActiveSession>>,
f: impl FnOnce() -> T,
) -> TExpand description
Run f with session active for seal/open on this thread, restoring the prior session after
(mirrors with_suite).
pub fn with_session<T>(
session: Option<Rc<dyn ActiveSession>>,
f: impl FnOnce() -> T,
) -> TRun f with session active for seal/open on this thread, restoring the prior session after
(mirrors with_suite).